==> haskell-pointed-5.0.5-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointed
version:              5.0.5
visibility:           public
id:                   pointed-5.0.5-41zisW8gkvu3z85pE3K8Fa
key:                  pointed-5.0.5-41zisW8gkvu3z85pE3K8Fa
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  5eedc929c3861a18a04733c582f16fde
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointed
hs-libraries:         HSpointed-5.0.5-41zisW8gkvu3z85pE3K8Fa
depends:
    base-4.17.2.1 comonad-5.0.9-9XYCuoUxdGmGG2uu9BeGYY containers-0.6.7
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    hashable-1.4.6.0-HsdqsQ7iDyd40AcboGWr8K
    kan-extensions-5.2.7-8DQzjHReP0qSMILtAL0Yt
    semigroupoids-6.0.1-ALhEB1ekwQkFChjKmHdaGN stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-DjNgsRwGYvfHy5WsKzKUzR

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.5-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointed
version:              5.0.5
visibility:           public
id:                   pointed-5.0.5-8gWFr6oC2kLUUOAePTDt0
key:                  pointed-5.0.5-8gWFr6oC2kLUUOAePTDt0
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  f12b0e4700e1e97992cc42eaf282d1f6
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointed
hs-libraries:         HSpointed-5.0.5-8gWFr6oC2kLUUOAePTDt0
depends:
    base-4.17.2.1 comonad-5.0.9-HhbbzCqu8yXCinyU8dzPDS containers-0.6.7
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    hashable-1.4.6.0-YmGjGgSp1PCYD264OAOUA
    kan-extensions-5.2.7-UXalNPRItmKetzBMOZDmR
    semigroupoids-6.0.1-JI2B6BEq5LTBs96WkqcLuZ stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-7E9U8fDCyyE7V5F5vC663n

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
